/**
TetrisCommand is a remake of the eponym game from Atari ST / Amiga
The program is developped under an event that took place on internet with the goal to make a game in a weekend
Copyright (C) 2014  Alexandre "LittleWhite" LAURENT

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

website: http://www.developpez.net/forums/d1465457/applications/developpement-2d-3d-jeux/projets/we-jv4-mix-weekend-tetriscommand/
e-mail: lw.demoscene@gmail.com
**/

#ifndef BLOCK_HPP
#define BLOCK_HPP

#include "NEngine/Types/Vec2.h"
#include "NEngine/Types/Rect.h"

#include <cstdlib>

#include "common.hpp"

struct Block
{
    enum State
    {
        LIVE,
        EXPLOSING,
        DEAD
    };

    Vec2<float> position;
    Rect block;

    unsigned int color;

    State m_state;

    Block(const IVec2& startingPosition, unsigned int color)
        :position(startingPosition.x,startingPosition.y),
         block(IVec2(startingPosition.x,startingPosition.y),USize2(BLOCK_SIZE,BLOCK_SIZE)),
         color(color),m_state(LIVE) {}

    Block(const IVec2& startingPosition)
        :position(startingPosition.x,startingPosition.y),
         block(IVec2(startingPosition.x,startingPosition.y),USize2(BLOCK_SIZE,BLOCK_SIZE)),
         color((rand()%(NB_TOTAL_COLORS-1))+1),m_state(LIVE)
    {}

    bool collides(const Block& other)const
    {
        if ( this->block.position.x+static_cast<int>(this->block.size.width) <= other.block.position.x )
            return false;
        if ( this->block.position.x >= other.block.position.x+static_cast<int>(other.block.size.width) )
            return false;
        if ( this->block.position.y+static_cast<int>(this->block.size.height) < other.block.position.y )
            return false;
        if ( this->block.position.y > other.block.position.y+static_cast<int>(other.block.size.height) )
            return false;

        return true;
    }

    bool isFrozen()const
    {
        return color == 0;
    }

    void fall(float speed)
    {
        position.y += speed;
        this->block.position.y = (int)position.y;
    }

    void explode()
    {
        m_state = EXPLOSING;
    }

    bool isExplosing()const
    {
        return m_state == EXPLOSING;
    }

    void die()
    {
        m_state = DEAD;
    }

    bool isDead()const
    {
        return m_state == DEAD;
    }
};

#endif
