#include "Bomb.hpp"

#include "NEngine/NEngine.h"
#include "NEngine/Sprite.h"
#include "NEngine/Renderer.h"

#include "Engine/AnimatedSprite.h"

#include "common.hpp"

Bomb::Bomb(const UVec2& startingPosition, const UVec2 destination, const NE::Sprite* pBombSprite, const NE::Sprite *pExplosionSprite)
    :m_position(startingPosition.x,startingPosition.y),m_startingPosition(startingPosition),m_destination(destination),
     m_pBombSprite(new AnimatedSprite(pBombSprite,USize2(BOMB_WIDTH,BOMB_HEIGHT),BOMB_ANIMATION_STEP_TIME)),
     m_pExplosionSprite(new AnimatedSprite(pExplosionSprite,USize2(EXPLOSION_WIDTH,EXPLOSION_HEIGHT),EXPLOSION_ANIMATION_STEP_TIME)),
     m_state(LIVE),m_explosionTime(0)
{

}

Bomb::~Bomb()
{
    delete m_pExplosionSprite;
    delete m_pBombSprite;
}

bool Bomb::render(NE::Renderer& renderer, const unsigned int time)
{
    switch (m_state)
    {
    case LIVE:
        return m_pBombSprite->draw(renderer,IVec2(m_position.x-BOMB_WIDTH/2,m_position.y-BOMB_HEIGHT/2),time);
        break;
    case EXPLODING:
        if ( m_explosionTime == 0 )
        {
            m_explosionTime=time;
        }

        if ( time-m_explosionTime > EXPLOSION_ANIMATION_STEP_TIME*6)
        {
            m_state = DEAD;
            return true;
        }
        return m_pExplosionSprite->draw(renderer,IVec2(m_position.x-EXPLOSION_WIDTH/2,m_position.y-EXPLOSION_HEIGHT/2),time);
        break;
    default:
        return true;
    }
}

void Bomb::update(float speed)
{
    if ( m_state != LIVE )
    {
        return;
    }

    Vec2<float> dir = Vec2<float>(static_cast<int>(m_destination.x)-static_cast<int>(m_position.x),
                                  static_cast<int>(m_destination.y)-static_cast<int>(m_position.y));

    float norm= sqrt(dir.x*dir.x + dir.y * dir.y);
    if ( norm < 3 )
    {
        m_state = EXPLODING;
        return;
    }

    dir.x = dir.x/norm;
    dir.y = dir.y/norm;

    m_position.x += dir.x * speed;
    m_position.y += dir.y * speed;
}
