/**
TetrisCommand is a remake of the eponym game from Atari ST / Amiga
The program is developped under an event that took place on internet with the goal to make a game in a weekend
Copyright (C) 2014  Alexandre "LittleWhite" LAURENT

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

website: http://www.developpez.net/forums/d1465457/applications/developpement-2d-3d-jeux/projets/we-jv4-mix-weekend-tetriscommand/
e-mail: lw.demoscene@gmail.com
**/

#include "PieceGenerator.hpp"

#include "NEngine/Exceptions/FileNotFoundException.h"

#include <fstream>
#include <sstream>

#include "common.hpp"

PieceGenerator::PieceGenerator()
{
    const char* pieceFiles[] =
    {
        PIECE_PATH "p1.txt",
        PIECE_PATH "p2.txt",
        PIECE_PATH "p3.txt",
        PIECE_PATH "p4.txt",
        PIECE_PATH "p5.txt",
        PIECE_PATH "p6.txt",
        PIECE_PATH "p7.txt",
        PIECE_PATH "p8.txt",
        PIECE_PATH "p9.txt",
        PIECE_PATH "p10.txt",
        PIECE_PATH "p11.txt",
        PIECE_PATH "p12.txt",
        PIECE_PATH "p13.txt"
    };

    for(unsigned int i = 0 ; i < sizeof(pieceFiles)/sizeof(char*) ; i++ )
    {
        std::ifstream pieceFile(pieceFiles[i]);
        if ( !pieceFile.is_open())
        {
            throw FileNotFoundException("Piece file " + std::string(pieceFiles[i]) + " not found");
        }

        std::string line;
        PieceGenerator::Piece piece;

        while (std::getline(pieceFile,line))
        {
            PieceGenerator::Line l;
            int value = 0;
            std::istringstream iss(line);

            while (iss >> value)
            {
                l.push_back(value);
            }

            piece.push_back(l);
        }
        m_shapes.push_back(piece);

        pieceFile.close();
    }
}

const std::list<Block> PieceGenerator::getPiece()const
{
    int draw = rand()%m_shapes.size();
    int color = (rand()%(NB_TOTAL_COLORS-1))+1;
    std::list<Block> piece;
    int posx = rand()%(GAME_AREA-m_shapes[draw][0].size()*BLOCK_SIZE);

    for ( int y = 0 ; y < static_cast<int>(m_shapes[draw].size()) ; y ++ )
    {
        for ( int x = 0 ; x < static_cast<int>(m_shapes[draw][y].size()) ; x++ )
        {
            if ( m_shapes[draw][y][x] == 1 )
            {
                piece.push_back(Block(IVec2(BLOCK_SIZE*x + PIECE_START_POSX + posx,
                                            BLOCK_SIZE*y + PIECE_START_POSY),color));
            }
        }
    }

    return piece;
}
