/**
TetrisCommand is a remake of the eponym game from Atari ST / Amiga
The program is developped under an event that took place on internet with the goal to make a game in a weekend
Copyright (C) 2014  Alexandre "LittleWhite" LAURENT

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

website: http://www.developpez.net/forums/d1465457/applications/developpement-2d-3d-jeux/projets/we-jv4-mix-weekend-tetriscommand/
e-mail: lw.demoscene@gmail.com
**/

#include "BoardGame.hpp"

#include "NEngine/NEngine.h"
#include "NEngine/Renderer.h"
#include "NEngine/Sprite.h"
#include "NEngine/Types/Rect.h"

#include "Game/Engine/Font.hpp"
#include "common.hpp"

BoardGame::BoardGame(const NE::Sprite* pBorderSprite, const NE::Sprite *pLineSprite, const NE::Sprite* pCitySprite, const NE::Sprite *pScoreSprite, const NE::Sprite *pLevelSprite, const NE::Sprite *pBlocksSprite, const NE::Sprite *pBombsSprite, const NE::Sprite *pSpeedSprite, const NE::Sprite *pTimeSprite, const NE::Sprite *pBonusSprite, Font* pFont)
    :m_pBorderSprite(pBorderSprite),m_pLineSprite(pLineSprite),m_pCitySprite(pCitySprite),
     m_pScoreSprite(pScoreSprite),m_pLevelSprite(pLevelSprite),m_pBlocksSprite(pBlocksSprite),
     m_pBombsSprite(pBombsSprite),m_pSpeedSprite(pSpeedSprite),m_pTimeSprite(pTimeSprite),
     m_pBonusSprite(pBonusSprite),m_bonusTime(false),
     m_pFont(pFont)
{
}

bool BoardGame::render(const NE::Renderer &renderer, const GameInfo& gi)
{
    bool result = true;
    // Display city
    result &= renderer.drawSurface(IVec2(PANEL_LEFT_POSX,CITY_POSY),m_pCitySprite);

    // Vertical borders
    for (unsigned int y = 0 ; y < WINDOW_HEIGHT ; y += m_pBorderSprite->getSize().height )
    {
         result &= renderer.drawSurface(IVec2(PANEL_LEFT_POSX,y),m_pBorderSprite);
         result &= renderer.drawSurface(IVec2(PANEL_RIGHT_POSX,y),m_pBorderSprite);
    }

    // Horizontal line (Base)
    unsigned int x;
    for ( x = PANEL_LEFT_POSX+m_pBorderSprite->getSize().width ;
          x < PANEL_RIGHT_POSX - m_pBorderSprite->getSize().height ;
          x+= m_pLineSprite->getSize().width )
    {
        result &= renderer.drawSurface(IVec2(x,BASE_LINE_POSY),m_pLineSprite);
    }
    // Last line
    result &= renderer.drawSurface(IVec2(x,BASE_LINE_POSY),m_pLineSprite, Rect(IVec2(0,0),
                                                                     USize2(PANEL_RIGHT_POSX-x,m_pLineSprite->getSize().height)));

    // Score
    result &= renderer.drawSurface(IVec2(0,SCORE_POSY),m_pScoreSprite);

    std::string scoreString = this->toString(gi.score);
    result &= m_pFont->draw(renderer,scoreString,IVec2(170-m_pFont->getStringSize(scoreString).width,SCORE_POSY+5));

    // Level
    result &= renderer.drawSurface(IVec2(0,LEVEL_POSY),m_pLevelSprite);

    std::string levelString = this->toString(gi.level);
    result &= m_pFont->draw(renderer,levelString,IVec2(170-m_pFont->getStringSize(levelString).width,LEVEL_POSY+5));

    // Score
    result &= renderer.drawSurface(IVec2(0,BLOCKS_POSY),m_pBlocksSprite);

    std::string blocksString = this->toString(gi.nbPiecesKilled);
    result &= m_pFont->draw(renderer,blocksString,IVec2(170-m_pFont->getStringSize(blocksString).width,BLOCKS_POSY+5));

    // Bonus
    // Bombs
    result &= renderer.drawSurface(IVec2(PANEL_RIGHT_POSX+10,BOMBS_POSY),m_pBombsSprite);

    std::string bombsString = this->toString(gi.bombNumber);
    result &= m_pFont->draw(renderer,bombsString,IVec2(WINDOW_WIDTH-70-m_pFont->getStringSize(bombsString).width,BOMBS_POSY+21));

    // Speed
    result &= renderer.drawSurface(IVec2(PANEL_RIGHT_POSX+10,SPEED_POSY),m_pSpeedSprite);

    std::string speedString = this->toString((static_cast<int>(gi.bombSpeed*100))/100.f);
    result &= m_pFont->draw(renderer,speedString,IVec2(WINDOW_WIDTH-70-m_pFont->getStringSize(speedString).width,SPEED_POSY+21));

    // Time
    result &= renderer.drawSurface(IVec2(PANEL_RIGHT_POSX+10,TIME_POSY),m_pTimeSprite);

    std::string timeString = this->toString(gi.shootDelay);
    result &= m_pFont->draw(renderer,timeString,IVec2(WINDOW_WIDTH-70-m_pFont->getStringSize(timeString).width,TIME_POSY+21));

    if ( m_bonusTime )
    {
        result &= renderer.drawSurface(IVec2(PANEL_RIGHT_POSX+10,BOMBS_POSY-2),m_pBonusSprite);
        result &= renderer.drawSurface(IVec2(PANEL_RIGHT_POSX+10,SPEED_POSY-2),m_pBonusSprite);

        if ( gi.shootDelay > 0 )
        {
            result &= renderer.drawSurface(IVec2(PANEL_RIGHT_POSX+10,TIME_POSY-2),m_pBonusSprite);
        }
    }

    return result;
}
